[gnus git] branch master updated: n0-13-49-g5b15466 =1= Fix spelling of "precede".

Katsumi Yamaoka <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  5b15466c9e3335702597014ca6b8c3d7436f7a7f (commit)
      from  c5b0e32708bb318800940824261c331cdc575dba (commit)


- Log -----------------------------------------------------------------
commit 5b15466c9e3335702597014ca6b8c3d7436f7a7f
Author: Glenn Morris <[email protected]>
Date:   Mon Feb 28 12:46:44 2011 +0000

    Fix spelling of "precede".

diff --git a/lisp/gnus-agent.el b/lisp/gnus-agent.el
index 204d63d..989488c 100644
--- a/lisp/gnus-agent.el
+++ b/lisp/gnus-agent.el
@@ -441,7 +441,7 @@ manipulated as follows:
                      (setf (gnus-agent-cat-groups old-category)
                            (delete group (gnus-agent-cat-groups
                                           old-category))))))
-               ;; Purge cache as preceeding loop invalidated it.
+               ;; Purge cache as preceding loop invalidated it.
                (setq gnus-category-group-cache nil))
 
              (setcdr (or (assq 'agent-groups category)
@@ -1195,7 +1195,7 @@ downloadable."
 	    (mapc #'gnus-summary-remove-process-mark
 		  (gnus-sorted-ndifference gnus-newsgroup-processable gnus-newsgroup-undownloaded))
 
-            ;; The preceeding call to (gnus-agent-summary-fetch-group)
+            ;; The preceding call to (gnus-agent-summary-fetch-group)
             ;; updated the temporary gnus-newsgroup-downloadable to
             ;; remove each article successfully fetched.  Now, I
             ;; update the real gnus-newsgroup-downloadable to only
@@ -1520,14 +1520,14 @@ downloaded into the agent."
            header-number)
       ;; Check each article
       (while (setq article (pop articles))
-        ;; Skip alist entries preceeding this article
+        ;; Skip alist entries preceding this article
         (while (> article (or (caar alist) (1+ article)))
           (setq alist (cdr alist)))
 
         ;; Prune off articles that we have already fetched.
         (unless (and (eq article (caar alist))
                      (cdar alist))
-          ;; Skip headers preceeding this article
+          ;; Skip headers preceding this article
           (while (> article
                     (setq header-number
                           (let* ((header (car headers)))
@@ -3437,7 +3437,7 @@ missing NOV entry.  Run gnus-agent-regenerate-group to restore it.")))
 
 		   ;; If considering all articles is set, I can only
 		   ;; expire article IDs that are no longer in the
-		   ;; active range (That is, articles that preceed the
+		   ;; active range (That is, articles that precede the
 		   ;; first article in the new alist).
 		   (if (and gnus-agent-consider-all-articles
 			    (>= article-number (car active)))
@@ -3715,7 +3715,7 @@ has been fetched."
 		   (gnus-agent-append-to-list tail-uncached v1))
                  (setq arts (cdr arts))
                  (setq ref (cdr ref)))
-                (t ; reference article (v2) preceeds the list being filtered
+                (t ; reference article (v2) precedes the list being filtered
                  (setq ref (cdr ref))))))
       (while arts
 	(gnus-agent-append-to-list tail-uncached (pop arts)))
@@ -4020,7 +4020,7 @@ If REREAD is not nil, downloaded articles are marked as unread."
 	;; article (with the exception of the last ID in the list - it's
 	;; special) that no longer appears in the overview.  In this
 	;; situtation, the last article ID in the list implies that it,
-	;; and every article ID preceeding it, have been fetched from the
+	;; and every article ID preceding it, have been fetched from the
 	;; server.
 
 	(if gnus-agent-consider-all-articles
diff --git a/lisp/gnus-start.el b/lisp/gnus-start.el
index d1ed23f..ebfa53f 100644
--- a/lisp/gnus-start.el
+++ b/lisp/gnus-start.el
@@ -1513,7 +1513,7 @@ If SCAN, request a scan of that group as well."
 	   (num 0))
 
       ;; These checks are present in gnus-activate-group but skipped
-      ;; due to setting dont-check in the preceeding call.
+      ;; due to setting dont-check in the preceding call.
 
       ;; If a cache is present, we may have to alter the active info.
       (when (and gnus-use-cache info)
@@ -1887,7 +1887,7 @@ If SCAN, request a scan of that group as well."
                             ;; OK - I'm done
                             (setq articles nil))
                            ((< range article)
-                            ;; this range preceeds the article. Leave the range unmodified.
+                            ;; this range precedes the article. Leave the range unmodified.
                             (pop ranges)
                             ranges)
                            ((= range article)
@@ -1910,11 +1910,11 @@ If SCAN, request a scan of that group as well."
                             (setcar ranges min)
                             ranges)
                            ((< max article)
-                            ;; this range preceeds the article. Leave the range unmodified.
+                            ;; this range precedes the article. Leave the range unmodified.
                             (pop ranges)
                             ranges)
                            ((< article min)
-                            ;; this article preceeds the range.  Return null to move to the
+                            ;; this article precedes the range.  Return null to move to the
                             ;; next article
                             nil)
                            (t
diff --git a/lisp/nntp.el b/lisp/nntp.el
index 09ecfb8..66a6365 100644
--- a/lisp/nntp.el
+++ b/lisp/nntp.el
@@ -1672,7 +1672,7 @@ password contained in '~/.nntp-authinfo'."
 
         ;; Some nntp servers seem to have an extension to the XOVER
         ;; extension.  On these servers, requesting an article range
-        ;; preceeding the active range does not return an error as
+        ;; preceding the active range does not return an error as
         ;; specified in the RFC.  What we instead get is the NOV entry
         ;; for the first available article.  Obviously, a client can
         ;; use that entry to avoid making unnecessary requests.  The

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/gnus-agent.el |   14 +++++++-------
 lisp/gnus-range.el |    8 ++++----
 lisp/gnus-start.el |    8 ++++----
 lisp/nntp.el       |    2 +-
 4 files changed, 16 insertions(+), 16 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
diff --git a/lisp/gnus-range.el b/lisp/gnus-range.el
index 794d164..ce5a837 100644
--- a/lisp/gnus-range.el
+++ b/lisp/gnus-range.el
@@ -116,10 +116,10 @@ Both ranges must be in ascending order."
                ;; All done with range2
                (setq r nil))
               ((< max1 min2)
                ;; No overlap: range1 preceeds range2
                (pop r))
               ((< max2 min1)
                ;; No overlap: range2 preceeds range1
                (pop range2))
               ((and (<= min2 min1) (<= max1 max2))
                ;; Complete overlap: range1 removed
@@ -232,10 +232,10 @@ RANGE1 and RANGE2 have to be sorted over <."
     (setq range1 (cdr range1)
           range2 (cdr range2))
     (while (and min1 min2)
-      (cond ((< max1 min2)              ; range1 preceeds range2
+      (cond ((< max1 min2)              ; range1 precedes range2
              (setq range1 (cdr range1)
                    min1 nil))
-            ((< max2 min1)              ; range2 preceeds range1
+            ((< max2 min1)              ; range2 precedes range1
              (setq range2 (cdr range2)
                    min2 nil))
             (t                     ; some sort of overlap is occurring
@@ -116,10 +116,10 @@ Both ranges must be in ascending order."
                (setq r nil))
               ((< max1 min2)
-               ;; No overlap: range1 preceeds range2
+               ;; No overlap: range1 precedes range2
                (pop r))
               ((< max2 min1)
@@ -116,10 +116,10 @@ Both ranges must be in ascending order."
                (pop r))
               ((< max2 min1)
-               ;; No overlap: range2 preceeds range1
+               ;; No overlap: range2 precedes range1
                (pop range2))
               ((and (<= min2 min1) (<= max1 max2))
-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.